// Copyright (c) 2002 David Muse
// See the COPYING file for more information.

	private:
		bool	initialize(const char *protocolname, int32_t number);
		protocolentryprivate	*pvt;
